# FullStory Snippet

FullStory's snippet package provides a number of ways to integrate the FullStory snippet with your build tooling of choice. For a more integrated experience, try the [browser SDK](https://www.npmjs.com/package/@fullstory/browser).

## Installation

#### with npm
```
npm i @fullstory/snippet --save
```

#### with yarn
```
yarn add @fullstory/snippet
```

## Exports
### `generateSnippetText`
#### Options
*  `orgId` -  Sets your FullStory Org Id. Find out how to get your Org Id [here](https://help.fullstory.com/hc/en-us/articles/360047075853). Required.
*  `host` - The recording server host domain. Can be set to direct recorded events to a proxy that you host. Defaults to `fullstory.com`.
*  `script` - The full location of the FullStory script (fs.js). FullStory hosts the `fs.js` recording script on a CDN, but you can choose to host a copy yourself. Defaults to `edge.fullstory.com/s/fs.js`.
* `namespace` - Sets the global identifier for FullStory when conflicts with `FS` arise; see [help](https://help.fullstory.com/hc/en-us/articles/360020624694-What-if-the-identifier-FS-is-used-by-another-script-on-my-site-). Defaults to `FS`.

#### Usage
Returns a stringified version of the FullStory snippet. This is useful for various build systems like webpack.

#### Examples

Webpack ([docs](https://github.com/jantimon/html-webpack-plugin#writing-your-own-templates))
```js
// webpack.config.js
{
  // ...
  plugins: [
    new HtmlWebpackPlugin({
      fsSnippet: generateSnippetText({ orgId: 'xyz' }),
      template: 'index.html',
    })
  ]
}

// index.html
<!DOCTYPE html>
<html>
  <head>
    <script><%= htmlWebpackPlugin.options.fsSnippet %></script>
  </head>
  <body>
  </body>
</html>
```

Gatsby ([docs](https://www.gatsbyjs.com/docs/reference/config-files/gatsby-ssr/#onRenderBody))
```js
// gatsby-ssr.js
exports.onRenderBody = ({ setHeadComponents }) => {
  setHeadComponent(
    <script
      dangerouslySetInnerHTML={{
        __html: generateSnippetTxt({ orgId: 'xyz' }),
      }}
    />
  );
}
```

### `initFS`
#### Options
Same as `generateSnippetText`.

#### Usage
Calling this function sets all the necessary global variables and immediately executes the FullStory snippet.

> NOTE: this is used internally by [@fullstory/browser](https://www.npmjs.com/package/@fullstory/browser).
